summaryrefslogtreecommitdiff
path: root/regress/lib/libssl/testdsa.sh
diff options
context:
space:
mode:
authorBob Beck <beck@cvs.openbsd.org>1999-09-29 10:06:21 +0000
committerBob Beck <beck@cvs.openbsd.org>1999-09-29 10:06:21 +0000
commit9b6ed5689f9caddcb960fa786cf42a9341d975d6 (patch)
tree3eae01adc5934ca1c634d6ec8bd0282737c7f566 /regress/lib/libssl/testdsa.sh
parent8a2ff2888721983d3df5cfa2def28affd57daaa7 (diff)
New minty openssl version
Diffstat (limited to 'regress/lib/libssl/testdsa.sh')
-rw-r--r--regress/lib/libssl/testdsa.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/regress/lib/libssl/testdsa.sh b/regress/lib/libssl/testdsa.sh
index dc5d7b97b56..e3afbfe40c5 100644
--- a/regress/lib/libssl/testdsa.sh
+++ b/regress/lib/libssl/testdsa.sh
@@ -1,25 +1,25 @@
#!/bin/sh
#Test DSA certificate generation of ssleay
cd $1
# Generate DSA paramter set
-ssleay dsaparam 512 -out dsa512.pem
+openssl dsaparam 512 -out dsa512.pem
if [ $? != 0 ]; then
exit 1;
fi
# Denerate a DSA certificate
-ssleay req -config $2/ssleay.cnf -x509 -newkey dsa:dsa512.pem -out testdsa.pem -keyout testdsa.key
+openssl req -config $2/openssl.cnf -x509 -newkey dsa:dsa512.pem -out testdsa.pem -keyout testdsa.key
if [ $? != 0 ]; then
exit 1;
fi
# Now check the certificate
-ssleay x509 -text -in testdsa.pem
+openssl x509 -text -in testdsa.pem
if [ $? != 0 ]; then
exit 1;
fi
@@ -1,25 +1,25 @@
#!/bin/sh
-#Test DSA certificate generation of ssleay
+#Test DSA certificate generation of openssl
cd $1
# Generate DSA paramter set